<?php

namespace Drupal\alexanders\Entity;

use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Interface AlexandersOrderItemInterface.
 *
 * @package Drupal\alexanders\Entity
 */
interface AlexandersOrderItemInterface extends ContentEntityInterface {

  /**
   * Get SKU of product in order item.
   *
   * @return string
   *   Product stock keeping unit.
   */
  public function getSku();

  /**
   * Set SKU of order item.
   *
   * @param string $sku
   *   Stock keeping unit.
   *
   * @return $this
   */
  public function setSku($sku);

  /**
   * Get QTY of order items printed by Alexanders.
   *
   * @return int
   *   # of items.
   */
  public function getQuantity();

  /**
   * Set number of times Alexanders should print this item.
   *
   * @param int $qty
   *   QTY of item that should be printed.
   *
   * @return $this
   */
  public function setQuantity($qty);

  /**
   * Get primary file associated with item.
   *
   * @return string
   *   URL for the order item.
   */
  public function getFile();

  /**
   * Set primary file URL.
   *
   * @param string $url
   *   Public URL for the image/pdf file.
   *
   * @return $this
   */
  public function setFile($url);

  /**
   * Get secondary file for item (guts or foil depending on product).
   *
   * @return string
   *   URL for the order item.
   */
  public function getAddFile();

  /**
   * Set secondary file URL.
   *
   * @param string $url
   *   Public URL for the image/pdf file.
   *
   * @return $this
   */
  public function setAddFile($url);

}
